==> FitGallery-0.85.tar.gz: FitGallery-0.85/www/config/config-lang.php <==
<?php

# FitGallery 0.85
# (C) Omar Lpez 'pollo' (pollo.es.pollo@gmail.com), Enrique D. Bosch 'presi' (presidev@confluencia.net) 
# http://fitgallery.presi.org

# Freely distributed by GNU GPL

# config language file
# add your tongue language and submit!

switch ($lang)
{
  case 'es': $text_galerias='Galer&iacute;as';
             $text_anterior='Anterior';
             $text_siguiente='Siguiente';
             $text_totales='Bytes totales: ';
             $text_medium='Tama&ntilde;o mediano';
             $text_powered='Funcionando con ';
             $text_images='im&aacute;genes';
             $text_pages='P&aacute;ginas';
             $text_exif='Informaci&oacute;n de Exif';
             $text_thpp='Im&aacute;genes por p&aacute;gina';
             $text_gapp='Galer&iacute;as por p&aacute;gina';
             $text_change='Cambiar';
             $text_exif_variable='Variable';
             $text_exif_thumbnail='Muestra';
             $text_exif_value='Valor';
             break;
  case 'en': $text_galerias='Galleries';
             $text_anterior='Previous';
             $text_siguiente='Next';
             $text_totales='Total bytes: ';
             $text_medium='Medium-size';
             $text_powered='Powered by ';
             $text_images='images';
             $text_pages='Pages';
             $text_exif='Exif information';
             $text_thpp='Thumbnails per page';
             $text_gapp='Galleries per page';
             $text_change='Change';
             $text_exif_variable='Variable';
             $text_exif_thumbnail='Thumbnail';
             $text_exif_value='Value';
             break;
  default: header('Content-type: text/plain');
           echo 'FitGallery: Language not supported.';
           exit();
}

?>

==> FitGallery-0.90.tar.gz: FitGallery-0.90/www/config/config-lang.php <==
<?php

# Config language file for FitGallery 0.90
# add your tongue language and submit!
# under public domain

switch ($lang)
{
  case 'es': $text_galerias='Galer&iacute;as';
             $text_anterior='Anterior';
             $text_siguiente='Siguiente';
             $text_totales='Bytes totales: ';
             $text_medium='Tama&ntilde;o mediano';
             $text_powered='Funcionando con ';
             $text_images='im&aacute;genes';
             $text_pages='P&aacute;ginas';
             $text_exif='Informaci&oacute;n de Exif';
             $text_thpp='Im&aacute;genes por p&aacute;gina';
             $text_gapp='Galer&iacute;as por p&aacute;gina';
             $text_change='Cambiar';
             $text_exif_section='Secci&oacute;n';
             $text_exif_variable='Variable';
             $text_exif_thumbnail='Muestra';
             $text_exif_value='Valor';
             break;
  case 'en': $text_galerias='Galleries';
             $text_anterior='Previous';
             $text_siguiente='Next';
             $text_totales='Total bytes: ';
             $text_medium='Medium-size';
             $text_powered='Powered by ';
             $text_images='images';
             $text_pages='Pages';
             $text_exif='Exif information';
             $text_thpp='Thumbnails per page';
             $text_gapp='Galleries per page';
             $text_change='Change';
             $text_exif_section='Section';
             $text_exif_variable='Variable';
             $text_exif_thumbnail='Thumbnail';
             $text_exif_value='Value';
             break;
  default: header('Content-type: text/plain');
           echo 'FitGallery: Language not supported.';
           exit();
}

?>
